<div align="center">
  <h1>RatioPath</h1>

<a href="https://pypi.org/project/ratiopath"><img alt="PyPI version" src="https://img.shields.io/pypi/v/ratiopath.svg?style=for-the-badge&labelColor=000000"></a>
<a href="https://github.com/RationAI/ratiopath/blob/main/LICENSE"><img alt="License" src="https://img.shields.io/npm/l/next.svg?style=for-the-badge&labelColor=000000"></a>
</div>

## Getting Started

RatioPath is a Python library for large-scale processing, analysis, and transformation of whole-slide pathology images (WSIs).  
It is built on top of the [Ray](https://www.ray.io/) framework to enable distributed, fault-tolerant, and scalable pipelines across multi-node environments.

- Visit our [Learn RatioPath](https://rationai.github.io/ratiopath/learn/get-started/quick-start/) course to get started with RatioPath.

## Documentation

Visit [https://rationai.github.io/ratiopath](https://rationai.github.io/ratiopath) to view the full documentation.
